@@ -1,10 +1,21 @@
+#  File R/zzz.R in package ergm.count, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
+#
+#  Copyright 2008-2016 Statnet Commons
+#######################################################################
 .onAttach <- function(lib, pkg){
   sm <- statnetStartupMessage("ergm.count",c("statnet"),FALSE)
   if(!is.null(sm)){
     packageStartupMessage(sm)
     packageStartupMessage(paste(c(strwrap(paste("NOTE: The form of the term ",sQuote("CMP")," has been changed in version 3.2 of ",sQuote("ergm.count"),". See the news or help('CMP') for more information.",sep="")),""),collapse="\n"))
   }
-
+}
+  
+.onLoad <- function(lib, pkg){    
   .RegisterMHPs()
   .RegisterConstraintImplications()
   .RegisterInitMethods()
